California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 002 - AB 247 (CH. 81, 2024) MURATSUCHI. EDUCATION FINANCE: SCHOOL FACILITIES: K-12 SCHOOLS AND LOCAL COMMUNITY COLLEGE PUBLIC EDUCATION FACILITIES MODERNIZATION, REPAIR AND SAFETY BOND ACT View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980478 | YES ON PROPOSITION 2 - COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | YES ON PROPOSITION 2 - COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE | SUPPORT